@@ -4,41 +4,42 @@ data_location = os.path.join(__dir__, "verilog")
 src = "https://github.com/cliffordwolf/picorv32"
 
 # Module version
-version_str = "1.0.post99"
-version_tuple = (1, 0, 99)
+version_str = "1.0.post194"
+version_tuple = (1, 0, 194)
 try:
     from packaging.version import Version as V
-    pversion = V("1.0.post99")
+    pversion = V("1.0.post194")
 except ImportError:
     pass
 
 # Data version info
-data_version_str = "1.0.post39"
-data_version_tuple = (1, 0, 39)
+data_version_str = "1.0.post52"
+data_version_tuple = (1, 0, 52)
 try:
     from packaging.version import Version as V
-    pdata_version = V("1.0.post39")
+    pdata_version = V("1.0.post52")
 except ImportError:
     pass
-data_git_hash = "f9b1beb4cfd6b382157b54bc8f38c61d5ae7d785"
-data_git_describe = "v1.0-39-gf9b1beb"
+data_git_hash = "f00a88c36eaab478b64ee27d8162e421049bcc66"
+data_git_describe = "v1.0-52-gf00a88c"
 data_git_msg = """\
-commit f9b1beb4cfd6b382157b54bc8f38c61d5ae7d785
-Author: Larry Doolittle <ldoolitt@recycle.lbl.gov>
-Date:   Mon Apr 27 17:23:45 2020 +0200
+commit f00a88c36eaab478b64ee27d8162e421049bcc66
+Merge: 1d9f5b7 e8dbd9a
+Author: Claire Xen <claire@clairexen.net>
+Date:   Mon Jan 3 16:03:13 2022 +0100
 
-    Make Makefile more flexible
+    Merge pull request #209 from YosysHQ/micko/cleanups
     
-    Signed-off-by: Claire Wolf <claire@symbioticeda.com>
+    Cleanups
 
 """
 
 # Tool version info
-tool_version_str = "0.0.post60"
-tool_version_tuple = (0, 0, 60)
+tool_version_str = "0.0.post142"
+tool_version_tuple = (0, 0, 142)
 try:
     from packaging.version import Version as V
-    ptool_version = V("0.0.post60")
+    ptool_version = V("0.0.post142")
 except ImportError:
     pass
 
